# If you don't want tests to be built,
# give rpmbuild option '--without tests'
%define with_tests %{!?_without_tests:1}%{?_without_tests:0}
%define without_tests %{?_without_tests:1}%{!?_without_tests:0}

%define section free

Summary:        Framework for running EJBs
Name:           mockejb
Version:        0.6
Release:        0.b2.2jpp
Epoch:          0
License:        Apache Software License
URL:            http://mockejb.sourceforge.net/
Group:          Development/Libraries/Java
Vendor:         JPackage Project
Distribution:   JPackage
Source0:        mockejb-0.6-beta2.zip
Patch0:         mockejb-0.6-build_properties.patch
Patch1:         mockejb-AllTests.patch
BuildRequires:  ant >= 0:1.6, ant-junit >= 0:1.6, jpackage-utils >= 0:1.5
BuildRequires:  junit, xml-commons-apis
BuildRequires:  asm
BuildRequires:  aspectj
BuildRequires:  cglib
BuildRequires:  easymock
BuildRequires:  jakarta-commons-logging
BuildRequires:  jakarta-cactus
BuildRequires:  oro
BuildRequires:  j2sdkee-1.3-sun
BuildRequires:  xdoclet
BuildRequires:  java2html
%if %{with_tests}
BuildRequires:  mockrunner
%endif

Requires:  jakarta-commons-logging
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
MockEJB is a lightweight framework for running EJBs. MockEJB 
implements javax.ejb APIs and creates Home and EJBObject 
implementation classes for your EJBs. Internally, MockEJB relies 
on dynamic proxies and interceptors. MockEJB has two primary usages:
* It allows for running EJBs outside of the container for unit 
  testing.You can run EJBs directly from your favorite IDE with 
  the minimal setup effort.
* It allows for deploying mock EJBs (i.e., mock EJB implementation 
  classes) into the container. Mock EJBs provide very effective way 
  of isolating EJBs under test from the rest of the application. 
  Mock EJBs return predefined test data and can override the actual 
  "non-mock" deployed EJBs. Once again, the purpose of MockEJB is 
  twofold and it works inside and outside of the container. So you 
  can benefit from it even if you continue running all your test 
  classes inside the container using Cactus. 
Additionally, MockEJB comes with the "mock" implementation of non-EJB 
APIs. Currently it provides in-memory JNDI and JMS implementations 
which can be used independently from MockEJB's EJB support.
MockEJB is not a full-blown EJB container. It does not fully implement 
J2EE/EJB specs, however it supports all vital APIs. 

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

%package manual
Summary:        Manual for %{name}
Group:          Development/Documentation

%description manual
%{summary}.

%prep
%setup -q -n %{name}-%{version}-beta2
# remove all binary libs
for j in $(find . -name "*.jar"); do
	mv $j $j.no
done
cp build.properties.sample build.properties

%patch0 -b .sav
%patch1 -b .sav
cp build.properties build_test.properties

%build
mkdir cactus-lib
pushd cactus-lib
ln -sf $(build-classpath aspectjrt) .
ln -sf $(build-classpath cactus-13/cactus) .
ln -sf $(build-classpath asm/asm) .
%if %{with_tests}
ln -sf $(build-classpath mockrunner/mockrunner) .
ln -sf $(build-classpath mockrunner/mockrunner-ejb) .
%endif
popd
export OPT_JAR_LIST="ant/ant-junit junit"
%if %{with_tests}
export CLASSPATH=$(build-classpath mockrunner)
ant build test
%else
ant -f build_mockejb.xml build
%endif

%install
rm -rf $RPM_BUILD_ROOT

# jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}

cp -p build/%{name}/%{name}-%{version}-beta2/lib/%{name}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}/j2h
cp -pr build/%{name}/%{name}-%{version}-beta2/doc/javadoc/* \
	$RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr build/%{name}/%{name}-%{version}-beta2/doc/java2html/* \
	$RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}/j2h
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}


rm -rf build/%{name}/%{name}-%{version}-beta2/doc/{javadoc,java2html}

# manual
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -pr build/%{name}/%{name}-%{version}-beta2/doc/* \
	$RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%post javadoc
rm -f %{_javadocdir}/%{name}
ln -s %{name}-%{version} %{_javadocdir}/%{name}

%postun javadoc
if [ "$1" = "0" ]; then
  rm -f %{_javadocdir}/%{name}
fi

%files
%defattr(0644,root,root,0755)
%{_javadir}/*.jar
%doc %{_docdir}/%{name}-%{version}/ReleaseNotes.html

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%ghost %{_javadocdir}/%{name}

%files manual
%defattr(0644,root,root,0755)
%doc %{_docdir}/%{name}-%{version}

%changelog
* Fri Nov 11 2005 Ralph Apel <r.apel@r-apel.de> - 0:0.6-0.b2.2jpp
- Add OPT_JAR_LIST for tests
- Add BuildRequires for asm, aspectj
* Thu Oct 20 2005 Ralph Apel <r.apel@r-apel.de> - 0:0.6-0.b2.1jpp
- First JPackage build
